@@ -74,6 +74,7 @@ ohse <- function(df,
   no_need_to_convert <- converted <- converted_binary <- NULL
 
   # Leave some columns out of the logic
+  ignore <- unique(ignore)
   if (!is.null(ignore)) {
     if (!quiet) message(">>> Omitting transformations for ", vector2text(ignore))
     ignored <- select(df, any_of(ignore))
@@ -173,11 +174,13 @@ ohse <- function(df,
     }
     if (length(no_variance) > 0 & drop) {
       no_variance <- no_variance[no_variance %in% ignore]
-      if (length(no_variance) > 0) message(paste0(
-        ">>> Automatically dropped ", length(no_variance),
-        " columns with 0% or >=", round(variance * 100),
-        "% variance: ", vector2text(no_variance)
-      ))
+      if (length(no_variance) > 0) {
+        message(paste0(
+          ">>> Automatically dropped ", length(no_variance),
+          " columns with 0% or >=", round(variance * 100),
+          "% variance: ", vector2text(no_variance)
+        ))
+      }
     }
   }
 
@@ -185,11 +188,11 @@ ohse <- function(df,
   if (drop) {
     df <- df[, c(!colnames(df) %in% c(converted, no_variance))]
   }
-  
+
   # Bind ignored untouched columns and order
   order <- order[order %in% colnames(df)]
   df <- bind_cols(df, ignored) %>% select(any_of(order), everything())
-  
+
   return(as_tibble(df))
 }
 
